@@ -1,11 +1,11 @@
-#!/usr/bin/env python3
+#!/usr/bin/env python
+
+"""Test suite for various audio contents handling methods"""
 
 import os
-import tempfile
 from pathlib import Path
-from shutil import rmtree
 from subprocess import run
-from unittest import TestCase, main
+from unittest import main
 
 from basic_test_case import BasicTestCase
 
@@ -20,11 +20,9 @@ from readalongs.audio_utils import (
 from readalongs.log import LOGGER
 
 
-def segments_from_pairs(*pairs):
-    return list({"begin": b, "end": e} for b, e in pairs)
-
-
 class TestAudio(BasicTestCase):
+    """Test suite for various audio contents handling methods"""
+
     def setUp(self):
         super().setUp()
         self.audio_segment = read_audio_from_file(
@@ -35,6 +33,7 @@ class TestAudio(BasicTestCase):
         )
 
     def align(self, input_text_path, input_audio_path, output_path, flags):
+        """Wrapper for invoking readalongs align via subprocess.run"""
         args = [
             "readalongs",
             "align",
@@ -45,13 +44,18 @@ class TestAudio(BasicTestCase):
         LOGGER.info(
             f"Aligning {input_text_path} and {input_audio_path}, outputting to {output_path}"
         )
-        return run(args, capture_output=True)
+        return run(args, capture_output=True, check=False, encoding="utf-8")
 
     def test_mute_section(self):
         """Should mute section of audio"""
+        max_before = self.audio_segment[1000:2000].max
         muted_segment = mute_section(self.audio_segment, 1000, 2000)
         muted_section = muted_segment[1000:2000]
-        self.assertLessEqual(muted_section.max, 1)
+        # This worked with pydub 0.23.1, but it does not work with 0.25.1
+        # self.assertLessEqual(muted_section.max, 1)
+        # Muting applies a gain of -120, so the results is not necessarily 0,
+        # it's just much smaller.
+        self.assertLessEqual(muted_section.max, max_before / 1000)
 
     def test_remove_section(self):
         """Should remove section of audio"""
@@ -71,19 +75,22 @@ class TestAudio(BasicTestCase):
         # Align
         input_text_path = os.path.join(self.data_dir, "audio_sample.txt")
         input_audio_path = os.path.join(self.data_dir, "audio_sample.ogg")
-        flags = ["-i", "-l", "eng"]
+        flags = ["-l", "eng"]
         output_path = os.path.join(self.tempdir, "output")
-        log = self.align(input_text_path, input_audio_path, output_path, flags)
-        # LOGGER.info(str(log))
+        process = self.align(input_text_path, input_audio_path, output_path, flags)
+        if process.returncode != 0:
+            LOGGER.error("Subprocess readalongs align failed: %s", process.stderr)
         # Check Result
-        smilpath = Path(output_path)
-        smil_files = smilpath.glob("*.smil")
+        raspath = Path(output_path)
+        ras_files = raspath.glob("*.readalong")
         self.assertTrue(
-            next(smil_files, False),
-            "No *.smil files found; "
-            "a fresh pip install might be required if dependencies changed.",
+            next(ras_files, False),
+            "No *.readalong files found; "
+            "pip install --force-reinstall --upgrade might be required "
+            "if dependencies changed.",
         )
-        self.assertFalse("error" in str(log).lower())
+        # Make sure ss logs are disabled
+        self.assertNotIn("Current configuration", process.stderr)
 
     def test_align_removed(self):
         """Try aligning section with removed audio"""
@@ -95,19 +102,22 @@ class TestAudio(BasicTestCase):
         # Align
         input_text_path = os.path.join(self.data_dir, "audio_sample.txt")
         input_audio_path = audio_output_path
-        flags = ["-i", "-l", "eng"]
+        flags = ["-l", "eng", "--debug-aligner"]
         output_path = os.path.join(self.tempdir, "output_removed")
-        log = self.align(input_text_path, input_audio_path, output_path, flags)
-        # LOGGER.info(str(log))
+        process = self.align(input_text_path, input_audio_path, output_path, flags)
+        if process.returncode != 0:
+            LOGGER.error("Subprocess readalongs align failed: %s", process.stderr)
         # Check Result
-        smilpath = Path(output_path)
-        smil_files = smilpath.glob("*.smil")
+        raspath = Path(output_path)
+        ras_files = raspath.glob("*.readalong")
         self.assertTrue(
-            next(smil_files, False),
-            "No *.smil files found; "
-            "a fresh pip install might be required if dependencies changed.",
+            next(ras_files, False),
+            "No *.readalong files found; "
+            "pip install --force-reinstall --upgrade might be required "
+            "if dependencies changed.",
         )
-        self.assertFalse("error" in str(log).lower())
+        # Make sure ss logs are enabled
+        self.assertIn("Current configuration", process.stderr)
 
     def test_align_muted(self):
         """Try aligning section with muted audio"""
@@ -119,21 +129,23 @@ class TestAudio(BasicTestCase):
         # Align
         input_text_path = os.path.join(self.data_dir, "audio_sample.txt")
         input_audio_path = audio_output_path
-        flags = ["-i", "-l", "eng", "-b"]
+        flags = ["-l", "eng", "-b"]
         output_path = os.path.join(self.tempdir, "output_muted")
-        log = self.align(input_text_path, input_audio_path, output_path, flags)
-        # LOGGER.info(str(log))
+        process = self.align(input_text_path, input_audio_path, output_path, flags)
+        if process.returncode != 0:
+            LOGGER.error("Subprocess readalongs align failed: %s", process.stderr)
         # Check Result
-        smilpath = Path(output_path)
-        smil_files = smilpath.glob("*.smil")
+        raspath = Path(output_path)
+        ras_files = raspath.glob("*.readalong")
         self.assertTrue(
-            next(smil_files, False),
-            "No *.smil files found; "
-            "a fresh pip install might be required if dependencies changed.",
+            next(ras_files, False),
+            "No *.readalong files found; "
+            "pip install --force-reinstall --upgrade might be required "
+            "if dependencies changed.",
         )
-        self.assertFalse("error" in str(log).lower())
 
     def test_extract_section(self):
+        """Unit test extract_section()"""
         self.assertEqual(len(extract_section(self.audio_segment, 1000, 2000)), 1000)
         self.assertEqual(len(extract_section(self.audio_segment, None, 500)), 500)
         self.assertEqual(
@@ -141,6 +153,20 @@ class TestAudio(BasicTestCase):
             len(self.audio_segment) - 1000,
         )
 
+    def test_write_audio_to_file(self):
+        """Mininal unit testing for write_audio_to_file"""
+        section = extract_section(self.audio_segment, 1000, 2000)
+        output_path = os.path.join(self.tempdir, "section_output.mp3")
+        write_audio_to_file(section, output_path)
+        self.assertTrue(os.path.exists(output_path))
+        reloaded_section = read_audio_from_file(output_path)
+        self.assertAlmostEqual(
+            len(section),
+            len(reloaded_section),
+            msg="reloaded audio file is more than 50ms shorter or longer",
+            delta=50,
+        )
+
 
 if __name__ == "__main__":
     main()
